@@ -3,11 +3,6 @@ class InvalidNMEAMessageException(Exception):
     pass
 
 
-class InvalidChecksumException(Exception):
-    """Invalid Checksum"""
-    pass
-
-
 class UnknownMessageException(Exception):
     """Message not supported yet"""
     pass
